/*
 * WipeFreeSpaceGUIAboutBox.java, part of the WipeFreeSpaceGUI package.
 *
 * Copyright (C) 2009-2012 Bogdan Drozdowski, bogdandr (at) op.pl
 * License: GNU General Public License, v3+
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 3
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foudation:
 *		Free Software Foundation
 *		51 Franklin Street, Fifth Floor
 *		Boston, MA 02110-1301
 *		USA
 *
 */
package BogDroSoft.wfs;

import java.awt.Cursor;
import java.awt.Desktop;
import java.awt.event.MouseEvent;
import java.io.InputStream;
import java.net.URI;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * The "About" box for the WipeFreeSpaceGUI program.
 * @author Bogdan 'bogdro' Drozdowski
 */
public class WipeFreeSpaceGUIAboutBox extends javax.swing.JDialog
{

	private static final long serialVersionUID = 65L;
	private static final Pattern emailPat =
			Pattern.compile ("\\b([\\.\\w]+@[\\.\\w]+)\\b");	// NOI18N
	private static final Pattern wwwPat =
			Pattern.compile ("([\\w]+)://([^</\"]+)([^<\"]*)<");	// NOI18N

	/**
	 * Creates an "about" box for the WipeFreeSpaceGUI program.
	 * @param parent The parent window to use.
	 */
	public WipeFreeSpaceGUIAboutBox (java.awt.Frame parent)
	{
		super (parent, true); // true -> modal
		initComponents ();
		getRootPane ().setDefaultButton (closeButton);
		closeButton.requestFocusInWindow ();
		appVendorLabel.setCursor (Cursor.getPredefinedCursor (Cursor.HAND_CURSOR));
		appHomepageLabel.setCursor (Cursor.getPredefinedCursor (Cursor.HAND_CURSOR));
		licenseText.setText (getFileContents (getClass ().getClassLoader ().getResourceAsStream ("BogDroSoft/wfs/resources/GNU-GPLv3.txt")));	// NOI18N
		licenseText.setCaretPosition (0);
		fontSizeSpin.setValue (fontSizeSpin.getValue ());	// refresh the font in the window

		/* add the Esc key listener to the frame and all components. */
		new WipeFreeSpaceGUI.EscKeyListener (this);
	}

	/**
	 * The Action to launch when the user presses the "Close" button.
	 * Has to be public.
	 */
	@org.jdesktop.application.Action
	public void closeAboutBox ()
	{
		dispose ();
	}

	/**
	 * This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        closeButton = new javax.swing.JButton();
        javax.swing.JLabel appTitleLabel = new javax.swing.JLabel();
        javax.swing.JLabel versionLabel = new javax.swing.JLabel();
        javax.swing.JLabel appVersionLabel = new javax.swing.JLabel();
        javax.swing.JLabel vendorLabel = new javax.swing.JLabel();
        appVendorLabel = new javax.swing.JLabel();
        javax.swing.JLabel homepageLabel = new javax.swing.JLabel();
        appHomepageLabel = new javax.swing.JLabel();
        javax.swing.JLabel appDescLabel = new javax.swing.JLabel();
        javax.swing.JLabel imageLabel = new javax.swing.JLabel();
        jScrollPane1 = new javax.swing.JScrollPane();
        licenseText = new javax.swing.JTextArea();
        fontSizeLab = new javax.swing.JLabel();
        fontSizeSpin = new javax.swing.JSpinner();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(BogDroSoft.wfs.WipeFreeSpaceGUI.class).getContext().getResourceMap(WipeFreeSpaceGUIAboutBox.class);
        setTitle(resourceMap.getString("title")); // NOI18N
        setModal(true);
        setName("aboutBox"); // NOI18N

        javax.swing.ActionMap actionMap = org.jdesktop.application.Application.getInstance(BogDroSoft.wfs.WipeFreeSpaceGUI.class).getContext().getActionMap(WipeFreeSpaceGUIAboutBox.class, this);
        closeButton.setAction(actionMap.get("closeAboutBox")); // NOI18N
        closeButton.setName("closeButton"); // NOI18N

        appTitleLabel.setFont(appTitleLabel.getFont().deriveFont(appTitleLabel.getFont().getStyle() | java.awt.Font.BOLD, appTitleLabel.getFont().getSize()+4));
        appTitleLabel.setText(resourceMap.getString("Application.title")); // NOI18N
        appTitleLabel.setName("appTitleLabel"); // NOI18N

        versionLabel.setFont(versionLabel.getFont().deriveFont(versionLabel.getFont().getStyle() | java.awt.Font.BOLD));
        versionLabel.setText(resourceMap.getString("versionLabel.text")); // NOI18N
        versionLabel.setName("versionLabel"); // NOI18N

        appVersionLabel.setText(resourceMap.getString("Application.version")); // NOI18N
        appVersionLabel.setName("appVersionLabel"); // NOI18N

        vendorLabel.setFont(vendorLabel.getFont().deriveFont(vendorLabel.getFont().getStyle() | java.awt.Font.BOLD));
        vendorLabel.setText(resourceMap.getString("vendorLabel.text")); // NOI18N
        vendorLabel.setName("vendorLabel"); // NOI18N

        appVendorLabel.setText("<html>Bogdan Drozdowski, <a href=\"mailto:bogdandr@op.pl\">bogdandr@op.pl</a></html>"); // NOI18N
        appVendorLabel.setName("appVendorLabel"); // NOI18N
        appVendorLabel.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                appVendorLabelMouseClicked(evt);
            }
        });

        homepageLabel.setFont(homepageLabel.getFont().deriveFont(homepageLabel.getFont().getStyle() | java.awt.Font.BOLD));
        homepageLabel.setText(resourceMap.getString("homepageLabel.text")); // NOI18N
        homepageLabel.setName("homepageLabel"); // NOI18N

        appHomepageLabel.setText("<html><a href=\"http://wipefreespace.sf.net\">http://wipefreespace.sf.net</a></html>"); // NOI18N
        appHomepageLabel.setName("appHomepageLabel"); // NOI18N
        appHomepageLabel.addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                appHomepageLabelMouseClicked(evt);
            }
        });

        appDescLabel.setText(resourceMap.getString("appDescLabel.text")); // NOI18N
        appDescLabel.setName("appDescLabel"); // NOI18N

        imageLabel.setIcon(resourceMap.getIcon("imageLabel.icon")); // NOI18N
        imageLabel.setName("imageLabel"); // NOI18N

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        licenseText.setColumns(20);
        licenseText.setEditable(false);
        licenseText.setRows(5);
        licenseText.setName("licenseText"); // NOI18N
        jScrollPane1.setViewportView(licenseText);

        fontSizeLab.setText(resourceMap.getString("fontSizeLab.text")); // NOI18N
        fontSizeLab.setName("fontSizeLab"); // NOI18N

        fontSizeSpin.setModel(new javax.swing.SpinnerNumberModel(Integer.valueOf(12), Integer.valueOf(1), null, Integer.valueOf(1)));
        fontSizeSpin.setName("fontSizeSpin"); // NOI18N
        fontSizeSpin.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                fontSizeSpinStateChanged(evt);
            }
        });

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addComponent(imageLabel)
                .addGap(18, 18, 18)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addGroup(layout.createSequentialGroup()
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(versionLabel)
                            .addComponent(vendorLabel)
                            .addComponent(homepageLabel))
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                            .addComponent(appVersionLabel)
                            .addComponent(appVendorLabel)
                            .addComponent(appHomepageLabel)))
                    .addComponent(appTitleLabel)
                    .addComponent(appDescLabel, javax.swing.GroupLayout.DEFAULT_SIZE, 403, Short.MAX_VALUE)
                    .addGroup(javax.swing.GroupLayout.Alignment.TRAILING, layout.createSequentialGroup()
                        .addComponent(fontSizeLab)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(fontSizeSpin, javax.swing.GroupLayout.PREFERRED_SIZE, 63, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED, 199, Short.MAX_VALUE)
                        .addComponent(closeButton))
                    .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 403, Short.MAX_VALUE))
                .addContainerGap())
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addComponent(imageLabel, javax.swing.GroupLayout.PREFERRED_SIZE, 316, Short.MAX_VALUE)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(appTitleLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(appDescLabel)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(versionLabel)
                    .addComponent(appVersionLabel))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(vendorLabel)
                    .addComponent(appVendorLabel))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(homepageLabel)
                    .addComponent(appHomepageLabel))
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                .addComponent(jScrollPane1, javax.swing.GroupLayout.DEFAULT_SIZE, 145, Short.MAX_VALUE)
                .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.UNRELATED)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(closeButton)
                    .addComponent(fontSizeLab)
                    .addComponent(fontSizeSpin, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addContainerGap())
        );

        appVendorLabel.getAccessibleContext().setAccessibleName(resourceMap.getString("appVendorLabel.AccessibleContext.accessibleName")); // NOI18N
        appHomepageLabel.getAccessibleContext().setAccessibleName(resourceMap.getString("appHomepageLab.AccessibleContext.accessibleName")); // NOI18N

        pack();
    }// </editor-fold>//GEN-END:initComponents

	private void appVendorLabelMouseClicked (java.awt.event.MouseEvent evt)//GEN-FIRST:event_appVendorLabelMouseClicked
	{//GEN-HEADEREND:event_appVendorLabelMouseClicked
		if ( evt.getButton () == MouseEvent.BUTTON1 )
		{
			if ( Desktop.isDesktopSupported () )
			{
				try
				{
					Desktop d = Desktop.getDesktop ();
					if ( d != null )
					{
						if ( d.isSupported (Desktop.Action.MAIL) )
						{
							Matcher m = emailPat.matcher (appVendorLabel.getText ());
							if ( m.find () )
							{
								d.mail (new URI ("mailto", // NOI18N
										m.group (1) + "?subject=[SOFT] WipeFreeSpaceGUI", null));	// NOI18N
							}
						}
					}
				}
				catch (Exception ex)
				{
					WipeFreeSpaceGUI.handleException (ex, "Desktop.mail");	// NOI18N
				}
			}
		}
	}//GEN-LAST:event_appVendorLabelMouseClicked

	private void appHomepageLabelMouseClicked (java.awt.event.MouseEvent evt)//GEN-FIRST:event_appHomepageLabelMouseClicked
	{//GEN-HEADEREND:event_appHomepageLabelMouseClicked
		if ( evt.getButton () == MouseEvent.BUTTON1 )
		{
			if ( Desktop.isDesktopSupported () )
			{
				try
				{
					Desktop d = Desktop.getDesktop ();
					if ( d != null )
					{
						if ( d.isSupported (Desktop.Action.BROWSE) )
						{
							Matcher m = wwwPat.matcher (appHomepageLabel.getText ());
							if ( m.find () )
							{
								Desktop.getDesktop ().browse (new URI (
										m.group (1), null, m.group (2),
										80, m.group (3), null, null));
							}
						}
					}
				}
				catch (Exception ex)
				{
					WipeFreeSpaceGUI.handleException (ex, "Desktop.browse");	// NOI18N
				}
			}
		}
	}//GEN-LAST:event_appHomepageLabelMouseClicked

	private void fontSizeSpinStateChanged (javax.swing.event.ChangeEvent evt)//GEN-FIRST:event_fontSizeSpinStateChanged
	{//GEN-HEADEREND:event_fontSizeSpinStateChanged
		Object val = fontSizeSpin.getValue ();
		if ( val != null && val instanceof Number )
			WipeFreeSpaceGUI.setFontSize (this, ((Number)val).floatValue ());
	}//GEN-LAST:event_fontSizeSpinStateChanged

	private String getFileContents (InputStream is)
	{
		StringBuilder ret = new StringBuilder (40000);
		byte[] read = new byte[1024];
		int wasRead;
		do
		{
			try
			{
				wasRead = is.read (read);
				ret.append (new String (read, 0, wasRead, "UTF-8"));	// NOI18N
			}
			catch (Exception ex)
			{
				WipeFreeSpaceGUI.handleException (ex, "InputStream.read");	// NOI18N
				wasRead = 0;
			}
		} while ( wasRead == read.length );
		try
		{
			is.close ();
		}
		catch (Exception ex)
		{
			WipeFreeSpaceGUI.handleException (ex, "InputStream.close");	// NOI18N
		}
		return ret.toString ();
	}

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel appHomepageLabel;
    private javax.swing.JLabel appVendorLabel;
    private javax.swing.JButton closeButton;
    private javax.swing.JLabel fontSizeLab;
    private javax.swing.JSpinner fontSizeSpin;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JTextArea licenseText;
    // End of variables declaration//GEN-END:variables
}
